package Acme::MetaSyntactic::apollo;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::apollo - The Apollo theme

=head1 DESCRIPTION

As from Apollo 9, the command and lunar modules of Project Apollo were
given radio call signs. This list document them.

Source: I<A Man on the Moon>, by Andrew Chaikin.

=head1 CONTRIBUTOR

Jean Forget.

Introduced in version 0.41, published on September 26, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
Gumdrop Spider
Charlie_Brown Snoopy
Columbia Eagle
Yankee_Clipper Intrepid
Odyssey Aquarius
Kitty_Hawk Antares
Endeavour Falcon
Casper Orion
America Challenger

