package Acme::MetaSyntactic::discworld;
use strict;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();
1;

=head1 NAME

Acme::MetaSyntactic::discworld - The discworld theme

=head1 DESCRIPTION

This theme contains items from Terry Pratchett's Disc World series.

=head1 CONTRIBUTOR

Martin Vorländer.

Introduced in version 0.42, published on October 3, 2005.

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=cut

__DATA__
# names
rincewind twoflower death nanny_ogg granny_weatherwax magrat_garlick
mustrum_ridcully ponder_stibbons windle_poons eric mort ysabell
alberto_malich lord_vetinari greebo pteppic ptraci captain_vimes carrot
detritus sergeant_colon nobby reg_shoe errol gaspode bel_shamharoth
offler creosote conina nijel koomi ksandra granpone bravd weasel tethis
bathys garhartra dibbler gaffer silverfish

ankh_morpork the_broken_drum dunmanifestin wyrmberg nef sto_lat lancre
cori_celesti tsort pseudopolis sto_helit klatch quirm

